==> jc-1.4.0.tar.gz: gnu/java/rmi/server/UnicastRemoteStub.h <==
// public class gnu.java.rmi.server.UnicastRemoteStub

// class file dependencies
// @dep_class 2773900486451b99 gnu_java_rmi_server_UnicastRemoteStub
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 46051fa019dc720f java_rmi_server_RemoteObject
// @dep_class b0c4f5e03c482057 java_rmi_server_RemoteStub

// header file dependencies
// @dep_header java_rmi_server_RemoteStub

#include "java/rmi/server/RemoteStub.h"

#ifndef _JC_gnu_java_rmi_server_UnicastRemoteStub_H_
#define _JC_gnu_java_rmi_server_UnicastRemoteStub_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_rmi_server_RemoteRef$object;
struct _jc_java_rmi_server_RemoteStub$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_UnicastRemoteStub$sub_refs	_jc_gnu_java_rmi_server_UnicastRemoteStub$sub_refs;
typedef struct _jc_gnu_java_rmi_server_UnicastRemoteStub$sub_nonrefs	_jc_gnu_java_rmi_server_UnicastRemoteStub$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_UnicastRemoteStub$refs	_jc_gnu_java_rmi_server_UnicastRemoteStub$refs;
typedef struct _jc_gnu_java_rmi_server_UnicastRemoteStub$nonrefs	_jc_gnu_java_rmi_server_UnicastRemoteStub$nonrefs;
typedef struct _jc_gnu_java_rmi_server_UnicastRemoteStub$object	_jc_gnu_java_rmi_server_UnicastRemoteStub$object;

typedef const struct _jc_gnu_java_rmi_server_UnicastRemoteStub$vmethods	_jc_gnu_java_rmi_server_UnicastRemoteStub$vmethods;
typedef const struct _jc_gnu_java_rmi_server_UnicastRemoteStub$vtable	_jc_gnu_java_rmi_server_UnicastRemoteStub$vtable;
typedef const struct _jc_gnu_java_rmi_server_UnicastRemoteStub$vtype	_jc_gnu_java_rmi_server_UnicastRemoteStub$vtype;

// Constructors
extern void _jc_gnu_java_rmi_server_UnicastRemoteStub$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_server_UnicastRemoteStub$object *);

// Static methods
extern void _jc_gnu_java_rmi_server_UnicastRemoteStub$method$setStubRef$269512082b083c26(_jc_env *, struct _jc_java_rmi_server_RemoteStub$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_gnu_java_rmi_server_UnicastRemoteStub$vmethods {
};

// Vtable
struct _jc_gnu_java_rmi_server_UnicastRemoteStub$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RemoteObject$vmethods	java_rmi_server_RemoteObject;
	_jc_java_rmi_server_RemoteStub$vmethods	java_rmi_server_RemoteStub;
	_jc_gnu_java_rmi_server_UnicastRemoteStub$vmethods	gnu_java_rmi_server_UnicastRemoteStub;
};

// Vtype
struct _jc_gnu_java_rmi_server_UnicastRemoteStub$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_UnicastRemoteStub$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_UnicastRemoteStub$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_UnicastRemoteStub$refs {
    _jc_gnu_java_rmi_server_UnicastRemoteStub$sub_refs	gnu_java_rmi_server_UnicastRemoteStub;
    _jc_java_rmi_server_RemoteStub$sub_refs	java_rmi_server_RemoteStub;
    _jc_java_rmi_server_RemoteObject$sub_refs	java_rmi_server_RemoteObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_UnicastRemoteStub$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_UnicastRemoteStub$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RemoteObject$sub_nonrefs	java_rmi_server_RemoteObject;
    _jc_java_rmi_server_RemoteStub$sub_nonrefs	java_rmi_server_RemoteStub;
    _jc_gnu_java_rmi_server_UnicastRemoteStub$sub_nonrefs	gnu_java_rmi_server_UnicastRemoteStub;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_UnicastRemoteStub$object {
	_jc_gnu_java_rmi_server_UnicastRemoteStub$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_UnicastRemoteStub$vtype	*vtype;
	_jc_gnu_java_rmi_server_UnicastRemoteStub$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_UnicastRemoteStub$vtype _jc_gnu_java_rmi_server_UnicastRemoteStub$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_UnicastRemoteStub, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_UnicastRemoteStub$class_object;

#endif	/* _JC_gnu_java_rmi_server_UnicastRemoteStub_H_ */

==> jc-1.4.6.tar.gz: gnu/java/rmi/server/UnicastRemoteStub.h <==
// public class gnu.java.rmi.server.UnicastRemoteStub

// class file dependencies
// @dep_class 2773900486451b99 gnu_java_rmi_server_UnicastRemoteStub
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8c9f90d92f098cf3 java_rmi_server_RemoteObject
// @dep_class b0c4f5e03c482057 java_rmi_server_RemoteStub

// header file dependencies
// @dep_header java_rmi_server_RemoteStub

#include "java/rmi/server/RemoteStub.h"

#ifndef _JC_gnu_java_rmi_server_UnicastRemoteStub_H_
#define _JC_gnu_java_rmi_server_UnicastRemoteStub_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_rmi_server_RemoteRef$object;
struct _jc_java_rmi_server_RemoteStub$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_UnicastRemoteStub$sub_refs	_jc_gnu_java_rmi_server_UnicastRemoteStub$sub_refs;
typedef struct _jc_gnu_java_rmi_server_UnicastRemoteStub$sub_nonrefs	_jc_gnu_java_rmi_server_UnicastRemoteStub$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_UnicastRemoteStub$refs	_jc_gnu_java_rmi_server_UnicastRemoteStub$refs;
typedef struct _jc_gnu_java_rmi_server_UnicastRemoteStub$nonrefs	_jc_gnu_java_rmi_server_UnicastRemoteStub$nonrefs;
typedef struct _jc_gnu_java_rmi_server_UnicastRemoteStub$object	_jc_gnu_java_rmi_server_UnicastRemoteStub$object;

typedef const struct _jc_gnu_java_rmi_server_UnicastRemoteStub$vmethods	_jc_gnu_java_rmi_server_UnicastRemoteStub$vmethods;
typedef const struct _jc_gnu_java_rmi_server_UnicastRemoteStub$vtable	_jc_gnu_java_rmi_server_UnicastRemoteStub$vtable;
typedef const struct _jc_gnu_java_rmi_server_UnicastRemoteStub$vtype	_jc_gnu_java_rmi_server_UnicastRemoteStub$vtype;

// Constructors
extern void _jc_gnu_java_rmi_server_UnicastRemoteStub$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_server_UnicastRemoteStub$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_java_rmi_server_UnicastRemoteStub$method$setStubRef$269512082b083c26(_jc_env *, struct _jc_java_rmi_server_RemoteStub$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_rmi_server_UnicastRemoteStub$vmethods {
};

// Vtable
struct _jc_gnu_java_rmi_server_UnicastRemoteStub$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RemoteObject$vmethods	java_rmi_server_RemoteObject;
	_jc_java_rmi_server_RemoteStub$vmethods	java_rmi_server_RemoteStub;
	_jc_gnu_java_rmi_server_UnicastRemoteStub$vmethods	gnu_java_rmi_server_UnicastRemoteStub;
};

// Vtype
struct _jc_gnu_java_rmi_server_UnicastRemoteStub$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_UnicastRemoteStub$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_UnicastRemoteStub$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_UnicastRemoteStub$refs {
    _jc_gnu_java_rmi_server_UnicastRemoteStub$sub_refs	gnu_java_rmi_server_UnicastRemoteStub;
    _jc_java_rmi_server_RemoteStub$sub_refs	java_rmi_server_RemoteStub;
    _jc_java_rmi_server_RemoteObject$sub_refs	java_rmi_server_RemoteObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_UnicastRemoteStub$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_UnicastRemoteStub$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RemoteObject$sub_nonrefs	java_rmi_server_RemoteObject;
    _jc_java_rmi_server_RemoteStub$sub_nonrefs	java_rmi_server_RemoteStub;
    _jc_gnu_java_rmi_server_UnicastRemoteStub$sub_nonrefs	gnu_java_rmi_server_UnicastRemoteStub;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_UnicastRemoteStub$object {
	_jc_gnu_java_rmi_server_UnicastRemoteStub$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_UnicastRemoteStub$vtype	*vtype;
	_jc_gnu_java_rmi_server_UnicastRemoteStub$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_UnicastRemoteStub$vtype _jc_gnu_java_rmi_server_UnicastRemoteStub$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_UnicastRemoteStub, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_UnicastRemoteStub$class_object;

#endif	/* _JC_gnu_java_rmi_server_UnicastRemoteStub_H_ */
